/******************************************************************************
* Project Name		: AN91162
* File Name			: main.c
* Version 			: 1.0
* Device Used		: CY8C4247LQI-BL483
* Software Used		: PSoC Creator 3.3 SP1
* Compiler    		: ARM GCC 4.9.3, ARM MDK Generic
* Related Hardware	: CY8CKIT-042-BLE Bluetooth Low Energy Pioneer Kit 
* Owner             : ROIT
*
********************************************************************************
* Copyright (2014), Cypress Semiconductor Corporation. All Rights Reserved.
********************************************************************************
* This software is owned by Cypress Semiconductor Corporation (Cypress)
* and is protected by and subject to worldwide patent protection (United
* States and foreign), United States copyright laws and international treaty
* provisions. Cypress hereby grants to licensee a personal, non-exclusive,
* non-transferable license to copy, use, modify, create derivative works of,
* and compile the Cypress Source Code and derivative works for the sole
* purpose of creating custom software in support of licensee product to be
* used only in conjunction with a Cypress integrated circuit as specified in
* the applicable agreement. Any reproduction, modification, translation,
* compilation, or representation of this software except as specified above 
* is prohibited without the express written permission of Cypress.
*
* Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, WITH 
* REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
* Cypress reserves the right to make changes without further notice to the 
* materials described herein. Cypress does not assume any liability arising out 
* of the application or use of any product or circuit described herein. Cypress 
* does not authorize its products for use as critical components in life-support 
* systems where a malfunction or failure may reasonably be expected to result in 
* significant injury to the user. The inclusion of Cypress' product in a life-
* support systems application implies that the manufacturer assumes all risk of 
* such use and in doing so indemnifies Cypress against all charges. 
*
* Use of this Software may be limited by and subject to the applicable Cypress
* software license agreement. 
*******************************************************************************/

/******************************************************************************
*                           THEORY OF OPERATION
*******************************************************************************
* This project showcases the capability of PSoC 4 BLE to communicate 
* with a BLE Central device over custom BLE service. The RGB LED custom service  
* allows read and write of attributes under the RGB characteristics.
* The LED control values sent to PSoC 4 BLE over BLE connection is converted to 
* respective color and intensity on the onboard RGB LED. The BLE central device 
* can be either CySmart mobile app, CySmart PC tool or third party App. 
* Refer to application note AN91162 for details.
*******************************************************************************
* No explicit Hardware connection is required. The LED is hard-wired on the BLE 
* Pioneer kit. The assigned pins are:
* R-G-B LED 	- P2[6], P3[6] and P3[7], respectively
******************************************************************************/
#include <main.h>

/*******************************************************************************
* Function Name: main
********************************************************************************
* Summary:
*        System entry point for starting components and application processing
*
* Parameters:
*  void
*
* Return:
*  int
*
*******************************************************************************/
int main()
{
    /* Start the components */
	InitializeSystem();

    for(;;)
    {
        /* Process BLE Events. This API pushes the BLE events from the stack
		* to the generic event callback function in the application. This  function
		* also pushes data from application to BLE stack for transmission */
		CyBle_ProcessEvents();
    }
}

/*******************************************************************************
* Function Name: InitializeSystem
********************************************************************************
* Summary:
*        Start the components in the projects.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void InitializeSystem(void)
{
	/* Enable Global Interrupt Mask */
	CyGlobalIntEnable;		
	
	/* Start BLE stack and register the event callback function. This function
	* will be called by BLE stack whenever an activity for application happens.
	* This function recieves various events from BLE stack and its corresponsing 
	* data */
	CyBle_Start(GeneralEventHandler);
	
}

/* [] END OF FILE */
